@@ -52,8 +52,11 @@ def call_git_describe(abbrev=4):
 def read_release_version():
     try:
         filename = resource_filename(Requirement.parse("MyClusterUI"),"share/MyClusterUI/RELEASE-VERSION")
-        f = open(filename, 'r')
-
+        if os.path.isfile(filename):
+            f = open(filename, 'r')
+        else:
+            filename = resource_filename(Requirement.parse("MyClusterUI"),"RELEASE-VERSION")
+            f = open(filename, 'r')
         try:
             version = f.readlines()[0]
             return version.strip()
